@@ -7,8 +7,9 @@ BW2stagePPS <- function(X, pp, psuID, lonely.SSU = "mean"){
         pp <-  pp[pick]
         psuID <- psuID[keep]
     }
-    
-    if (!(sum(pp)==1)) {stop("pp vector must sum to 1.\n") }
+
+    chk.pp <- abs(sum(pp) - 1) >= 1e-3
+    if (chk.pp){stop("pp vector must sum to 1.\n") }
 
     M <- length(unique(psuID))
     Ni <- table(psuID)
